@@ -609,6 +609,7 @@ class paircount(object):
             with utils.MapReduce(np=worker.np) as pool:
                 pool.map(worker.work, range(worker.size), reduce=worker.reduce)
 
+        self.weight = data1.norm * data2.norm
 
 class paircount_worker(object):
     """
@@ -689,20 +690,23 @@ class paircount_worker(object):
         import heapq
         def makeitem(n1, n2):
             if n1.size > n2.size:
-                return (-n1.size, n1, n2)
+                return (-n1.size, 0, (n1, n2))
             else:
-                return (-n2.size, n2, n1)
+                return (-n2.size, 1, (n1, n2))
         heap = []
         heapq.heappush(heap, makeitem(tree1, tree2))
         while len(heap) < np:
-            junk, n1, n2 = heapq.heappop(heap)
-            if n1.less is None: break
-            heapq.heappush(heap, makeitem(n1.less, n2))
-            heapq.heappush(heap, makeitem(n1.greater, n2))
+            junk, split, n = heapq.heappop(heap)
+            if n[split].less is None: break
+            item = list(n)
+            item[split] = n[split].less
+            heapq.heappush(heap, makeitem(*item))
+            item[split] = n[split].greater
+            heapq.heappush(heap, makeitem(*item))
         p = []
         while heap:
-            junk, n1, n2 = heapq.heappop(heap)
-            p.append((n1, n2))
+            junk, split, n = heapq.heappop(heap)
+            p.append(n)
         return p
 
     def __enter__(self):
@@ -757,7 +761,7 @@ class paircount_worker(object):
         self.pc.binning = self.bins
         self.pc.edges = self.bins.edges
         self.pc.centers = self.bins.centers
-        
+
         # add the mean centers info
         if self.bins.compute_mean_coords:
             
